# 3DeeCellTracker

This is a package used for segmenting and tracking cells in 3D time lapse images. The example scripts can be found in: https://github.com/WenChentao/3DeeCellTracker. The methods have been explained in Wen et al. bioRxiv 2018 (doi: https://doi.org/10.1101/385567) and in Wen et al. eLife 2021. The data for demonstration and the previous demo codes can be found in: http://ssbd.qbic.riken.jp/set/20190602/
